@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2012 - 2013 Michal Čihař <mcihar@suse.cz>
+# Copyright © 2012 - 2014 Michal Čihař <mcihar@suse.cz>
 #
 # This file is part of python-suseapi <https://github.com/nijel/python-suseapi>
 #
@@ -27,6 +27,8 @@ import httplib
 import socket
 import cookielib
 
+DEFAULT_TIMEOUT = 5.0
+
 
 class WebScraperError(Exception):
     '''
@@ -35,6 +37,22 @@ class WebScraperError(Exception):
     pass
 
 
+class TimeoutRequest(mechanize.Request):
+    '''
+    Request class with defined timeout.
+    '''
+    def __init__(self, url, data=None, headers=None,
+                 origin_req_host=None, unverifiable=False, visit=None,
+                 timeout=DEFAULT_TIMEOUT):
+        if headers is None:
+            headers = {}
+        mechanize.Request.__init__(
+            self, url, data, headers, origin_req_host,
+            unverifiable, visit, timeout
+        )
+        self.timeout = DEFAULT_TIMEOUT
+
+
 class WebScraper(object):
     '''
     Web based scraper using mechanize.
@@ -48,7 +66,9 @@ class WebScraper(object):
         self.cookiejar = cookielib.CookieJar()
 
         # Browser instance
-        self.browser = mechanize.Browser()
+        self.browser = mechanize.Browser(
+            request_class=TimeoutRequest
+        )
 
         # Set cookies
         self.browser.set_cookiejar(self.cookiejar)
@@ -100,7 +120,7 @@ class WebScraper(object):
 
     def request(self, action, paramlist=None, **kwargs):
         '''
-        Performs single request on SWAMP (loads single page).
+        Performs single request on a server (loads single page).
         '''
         url = self._get_req_url(action)
         if paramlist is not None:
@@ -109,13 +129,19 @@ class WebScraper(object):
             params = None
         else:
             params = urllib.urlencode(kwargs)
-        return self._safely(self.browser.open, url, params)
+        return self._safely(
+            self.browser.open,
+            url, params, timeout=DEFAULT_TIMEOUT
+        )
 
     def _submit(self):
         '''
         Submits currently selected browser form.
         '''
-        return self._safely(self.browser.submit)
+        return self._safely(
+            self.browser.submit,
+            request_class=TimeoutRequest
+        )
 
     def set_cookies(self, cookies):
         '''
@@ -129,15 +155,3 @@ class WebScraper(object):
         Returns cookies set in browser.
         '''
         return [cookie for cookie in self.cookiejar]
-
-
-def browser_init():
-    '''
-    Inits the mechanize with usable params.
-    '''
-    from mechanize import _sockettimeout
-
-    # Force default timeout, there is no better way to do this
-    _sockettimeout._GLOBAL_DEFAULT_TIMEOUT = 10
-
-browser_init()
